==========================
django-allauth-helper
==========================

Template pack for django-allauth_ using `Bootstrap 4`_.

.. _django-allauth: https://github.com/pennersr/django-allauth
.. _`Bootstrap 4`: http://getbootstrap.com/

Installation
==============

After successfully installing and configuring django-allauth, add `allauth_bootstrap4` to your `INSTALLED_APPS` *above* `allauth`.

The template pack uses the Bootstrap CDN. To customize the stylesheet links, see Customization_.

.. _Customization:
Customization
==============

Changing Bootstrap links 
-----------------------
TODO `account/parts/bootstrap.html`

Customizing page headers
------------------------
TODO `account/parts/header.html`
